==> hoteldruid-mod-bg_2.2.0-1.zip: bg/modifica_app.php <==
<?php

switch ($messaggio) {

case "contiene prenotazione future, non si può cancellare":	$messaggio = "съдържа бъдещи резервации, и не може да се изтрие"; break;
case "SI":  					$messaggio = "ДА"; break;
case "NO":  					$messaggio = "НЕ"; break;
case "Torna indietro":  			$messaggio = "обратно"; break;
case "La casa verrà cambiata da":  		$messaggio = "Сградата ще бъде променена от"; break;
case "a":  					$messaggio = "на"; break;
case "Il piano verrà cambiato da":  		$messaggio = "Етажът ще бъде променен от"; break;
case "Il massimo numero di occupanti verrà cambiato da":	$messaggio = "Максималният брой хора, които могат да се настанят ще бъде променен от"; break;
case "La priorità verrà cambiata da":  		$messaggio = "Приоритетът ще бъде променен от"; break;
case "Il commento verrà cambiato":  		$messaggio = "Коментарът ще бъде променен"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "Casa":  					$messaggio = "Сграда"; break;
case "Cambia in":  				$messaggio = "Променете на"; break;
case "Piano":  					$messaggio = "Етаж"; break;
case "Capienza":  				$messaggio = "Капацитет"; break;
case "Priorità":  				$messaggio = "Приоритет"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "Persone":  				$messaggio = "Души"; break;
case "anche se le loro caratteristiche non sono più compatibili":	$messaggio = "дори и ако техните характеристики вече не са съвместими"; break;
case "Nome":  		$messaggio = "Име"; break;
case "esiste già":  				$messaggio = "вече съществува"; break;
case "non esiste più":  			$messaggio = "вече не съществува"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "la nuova foto è stata aggiunta":  	$messaggio = "the new photo has been added"; break;
case "l'url della foto è sbagliata":  		$messaggio = "the photo url is wrong"; break;
case "foto eliminata":  			$messaggio = "photo deleted"; break;
case "elimina":  				$messaggio = "delete"; break;
case "url di una nuova foto":  			$messaggio = "new photo url"; break;
case "commento della foto":  			$messaggio = "comment of photo"; break;
case "aggiornato":  				$messaggio = "updated"; break;
case "aggiornata":  				$messaggio = "updated"; break;
case "modifica":  				$messaggio = "modify"; break;
case "commento":  				$messaggio = "comment"; break;
case "Persona":  				$messaggio = "Person"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/modifica_app.php <==
<?php

switch ($messaggio) {

case "contiene prenotazione future, non si può cancellare":	$messaggio = "съдържа бъдещи резервации, и не може да се изтрие"; break;
case "SI":  					$messaggio = "ДА"; break;
case "NO":  					$messaggio = "НЕ"; break;
case "Torna indietro":  			$messaggio = "обратно"; break;
case "La casa verrà cambiata da":  		$messaggio = "Сградата ще бъде променена от"; break;
case "a":  					$messaggio = "на"; break;
case "Il piano verrà cambiato da":  		$messaggio = "Етажът ще бъде променен от"; break;
case "Il massimo numero di occupanti verrà cambiato da":	$messaggio = "Максималният брой хора, които могат да се настанят ще бъде променен от"; break;
case "La priorità verrà cambiata da":  		$messaggio = "Приоритетът ще бъде променен от"; break;
case "Il commento verrà cambiato":  		$messaggio = "Коментарът ще бъде променен"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "Casa":  					$messaggio = "Сграда"; break;
case "Cambia in":  				$messaggio = "Променете на"; break;
case "Piano":  					$messaggio = "Етаж"; break;
case "Capienza":  				$messaggio = "Капацитет"; break;
case "Priorità":  				$messaggio = "Приоритет"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "Persone":  				$messaggio = "Души"; break;
case "anche se le loro caratteristiche non sono più compatibili":	$messaggio = "дори и ако техните характеристики вече не са съвместими"; break;
case "Nome":  		$messaggio = "Име"; break;
case "esiste già":  				$messaggio = "вече съществува"; break;
case "non esiste più":  			$messaggio = "вече не съществува"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "la nuova foto è stata aggiunta":  	$messaggio = "the new photo has been added"; break;
case "l'url della foto è sbagliata":  		$messaggio = "the photo url is wrong"; break;
case "foto eliminata":  			$messaggio = "photo deleted"; break;
case "elimina":  				$messaggio = "delete"; break;
case "url di una nuova foto":  			$messaggio = "new photo url"; break;
case "commento della foto":  			$messaggio = "comment of photo"; break;
case "aggiornato":  				$messaggio = "updated"; break;
case "aggiornata":  				$messaggio = "updated"; break;
case "modifica":  				$messaggio = "modify"; break;
case "commento":  				$messaggio = "comment"; break;
case "Persona":  				$messaggio = "Person"; break;
case "più bassa viene assegnata prima":  	$messaggio = "lower assigned first"; break;
case "Rimane solo":  				$messaggio = "It remains only"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
